@@ -11,12 +11,14 @@ from mqtt_hass_base import entity as mqtt_entity
 from mqtt_hass_base.error import MQTTHassBaseError
 
 ENTITY_TYPES = (
+    "button",
     "switch",
     "lock",
     "light",
     "binarysensor",
     "sensor",
     "vacuum",
+    "number",
 )
 
 
