@@ -4,9 +4,11 @@ from mqtt_hass_base.entity.binarysensor import (
     BinarySensorSettingsType,
     MqttBinarysensor,
 )
+from mqtt_hass_base.entity.button import ButtonSettingsType, MqttButton
 from mqtt_hass_base.entity.common import MqttEntity
 from mqtt_hass_base.entity.light import LightSettingsType, MqttLight
 from mqtt_hass_base.entity.lock import LockSettingsType, MqttLock
+from mqtt_hass_base.entity.number import MqttNumber, NumberSettingsType
 from mqtt_hass_base.entity.sensor import MqttSensor, SensorSettingsType
 from mqtt_hass_base.entity.switch import MqttSwitch, SwitchSettingsType
 from mqtt_hass_base.entity.vacuum import VACUUM_STATES, MqttVacuum, VacuumSettingsType
@@ -15,6 +17,10 @@ __all__ = [
     "MqttEntity",
     "MqttBinarysensor",
     "BinarySensorSettingsType",
+    "MqttButton",
+    "ButtonSettingsType",
+    "MqttNumber",
+    "NumberSettingsType",
     "MqttLight",
     "LightSettingsType",
     "MqttSensor",
